summaryrefslogtreecommitdiff
path: root/sw/inc/itabenum.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/inc/itabenum.hxx')
-rw-r--r--sw/inc/itabenum.hxx20
1 files changed, 10 insertions, 10 deletions
diff --git a/sw/inc/itabenum.hxx b/sw/inc/itabenum.hxx
index 0188267c0497..9dfa8c3a43b7 100644
--- a/sw/inc/itabenum.hxx
+++ b/sw/inc/itabenum.hxx
@@ -31,21 +31,21 @@
namespace tabopts
{
- const USHORT DEFAULT_BORDER = 0x01;
- const USHORT HEADLINE = 0x02;
-// const USHORT REPEAT = 0x04;
-// const USHORT HEADLINE_REPEAT = 0x06; // Headline + Repeat
- const USHORT SPLIT_LAYOUT = 0x08;
- const USHORT HEADLINE_NO_BORDER = HEADLINE | SPLIT_LAYOUT;
- const USHORT ALL_TBL_INS_ATTR = DEFAULT_BORDER | HEADLINE | SPLIT_LAYOUT;
+ const sal_uInt16 DEFAULT_BORDER = 0x01;
+ const sal_uInt16 HEADLINE = 0x02;
+// const sal_uInt16 REPEAT = 0x04;
+// const sal_uInt16 HEADLINE_REPEAT = 0x06; // Headline + Repeat
+ const sal_uInt16 SPLIT_LAYOUT = 0x08;
+ const sal_uInt16 HEADLINE_NO_BORDER = HEADLINE | SPLIT_LAYOUT;
+ const sal_uInt16 ALL_TBL_INS_ATTR = DEFAULT_BORDER | HEADLINE | SPLIT_LAYOUT;
}
struct SwInsertTableOptions
{
- USHORT mnInsMode;
- USHORT mnRowsToRepeat;
+ sal_uInt16 mnInsMode;
+ sal_uInt16 mnRowsToRepeat;
- SwInsertTableOptions( USHORT nInsMode, USHORT nRowsToRepeat ) :
+ SwInsertTableOptions( sal_uInt16 nInsMode, sal_uInt16 nRowsToRepeat ) :
mnInsMode( nInsMode ), mnRowsToRepeat( nRowsToRepeat ) {};
};